summaryrefslogtreecommitdiffstats
path: root/os-plugins/plugins/Theme/init-hooks/05-have-kernelvars/Theme.sh
diff options
context:
space:
mode:
Diffstat (limited to 'os-plugins/plugins/Theme/init-hooks/05-have-kernelvars/Theme.sh')
-rw-r--r--os-plugins/plugins/Theme/init-hooks/05-have-kernelvars/Theme.sh7
1 files changed, 4 insertions, 3 deletions
diff --git a/os-plugins/plugins/Theme/init-hooks/05-have-kernelvars/Theme.sh b/os-plugins/plugins/Theme/init-hooks/05-have-kernelvars/Theme.sh
index 48c08581..c249824c 100644
--- a/os-plugins/plugins/Theme/init-hooks/05-have-kernelvars/Theme.sh
+++ b/os-plugins/plugins/Theme/init-hooks/05-have-kernelvars/Theme.sh
@@ -1,7 +1,8 @@
# splashy stuff seems to depend on /proc/fb with VESA!?
# only activate with kernel option quiet
if grep -E "(VESA|VGA)" /proc/fb > /dev/null 2>&1 \
- && grep -qi " quiet " /proc/cmdline > /dev/null 2>&1 ; then
+ && grep -qi " quiet " /proc/cmdline > /dev/null 2>&1 \
+ && [ $DEBUGLEVEL -eq 0 ] ; then
export Theme_nosplash=0
else
export Theme_nosplash=1
@@ -1,7 +1,8 @@
-# splashy stuff seems to depend on /proc/fb with VESA!?
-# only activate with kernel option quiet
+# splashy depends on /proc/fb with VESA
+# only activate with kernel option quiet and no debuglevel
if grep -E "(VESA|VGA)" /proc/fb > /dev/null 2>&1 \